import axios from 'axios';
import store from "@/views/home/store/index";
import router from '@/views/home/router'

// 创建axios实例，设置配置得默认值
// const instance = axios.create({
//     baseUrl:'https://market.cebg.games',   // 这里写接口的http地址，
//     timeout: 5000,  // 设置请求超时的默认值
// })
let apiHost = process.env.NODE_ENV !== 'production' ? process.env.VUE_APP_API_HOST : document.location.host;
let scheme = document.location.protocol;
const instance = axios.create({
    baseURL: scheme + "//" + apiHost + '/api/',
    timeout: 5000
})

// 设置请求拦截器
instance.interceptors.request.use(
    config => {
        // 判断当前是否有token，有则在请求头上加上token
        // console.log(store)
        if (store.state.token) {
            config.headers.Authorization = "Bearer " + store.state.token
        }
        return config
    },
    error => {
        // 请求错误进行拦截并返回错误信息
        // console.log(error)
        return Promise.reject(error)
    }
)
// 设置响应拦截
instance.interceptors.response.use(
    response => {
        const res = response.data
        return res
    },
    error => {
        let response = error.response;
        if (response?.status === 401) {
            store.commit('del_token')
            router.replace('login')
        } else {
            console.error('response error', error.response);
        }
        return Promise.reject(error)
    }
)

export const Request = (method,Url:string,params? : object | any) =>
    instance({
        url: Url,
        method: method,
        params: params
    })

export function ExcelExport (Url,param?:object) {
    return axios({
        url: scheme + "//" + apiHost + '/api/'+Url,
        method: 'post',
        params: param,
        responseType: 'blob',
        headers:{
            Authorization : "Bearer " + store.state.token
        }
    })
}
