import { Component, Mixins, Vue, Watch } from 'vue-property-decorator'
import Url from "@/utils/Url";
import {
    State,
    Getter,
    Action,
    Mutation
} from "vuex-class";
import HomeParent from "@/views/home/Common/HomeParent";
import { ElTreeDataInterface,  } from "@/views/home/Common/Types";
import CustomPage from "@/components/page.vue";
import {Form, TableColumn} from "view-design";
import {Message, Tree} from "element-ui";
import {Request} from "@/utils/Request";

@Component({
    components : {
        CustomPage
    }
})
export default class Apply extends HomeParent {
    name: string = "apply";

    public Data = []
    public drawerTitle:string = '';
    public dialogFormVisible: boolean = false;
    public form: any = {
        item_id : null, send_account : null, reason : null
    }
    public rules: object = {
        item_id : [{required : true, trigger : "blur", "message" : "请填写道具id"}],
        send_account : [{required : true, trigger : "blur", "message" : "请填写发放账户"}],
        reason : [{required : true, trigger : "blur", "message" : "请填写申请原因"}],
    }
    public showApplyDialog:boolean = false;
    public DataDetail:any=[];
    public columns: TableColumn[] = [{
        title: "unikey",
        key: "unikey"
    },{
        title: "申请者",
        key: "creator_account"
    }, {
        title: "发放者",
        key: "send_account"
    }, {
        title: "ItemId",
        key: "item_id"
    }, {
        title: "申请时间",
        key: "create_time"
    },  {
        title: "初审状态",
        slot: "audit_state_one",
        align: 'center',
    },{
        title: "终审状态",
        slot: "audit_state_two",
        align: 'center',
    },  {
        title: "执行状态",
        slot: "execute_state",
        align: 'center',
    },{
        title: "操作",
        slot: "operation",
    }];

    public total: number = 0;
    public search: { page: number, size: number, keywords?: string } = {
        page: 1, size: 10, keywords: ""
    }


    @Watch("search.page")
    private _onPageChange(): void {
        this._getData()
    }

    @Watch("search.size")
    private _onPageSizeChange(): void {
        this.search.page = 1;
        this._getData()
    }

    public created(): void {
        this._getData();
    }

    public onDropdownEvent(name: string,row): void {
        switch (name) {
            case "show" : this.show(row);break;
            case "revocation" : this.revocation(row);break;
        }
    }

    public addEvent() {
        this.drawerTitle = '申请道具'
        this._initForm()
        this.dialogFormVisible = true
    }

    public saveEvent(){
        let form : Form = this.$refs["dataForm"] as Form;
        form.validate((valid : boolean) => {
            if (!valid) {
                return;
            }
            Request('post', Url.ADD_APPLY,this.form).then((res:any)=>{
                if (res.code == 200){
                    this.dialogFormVisible = false
                    this._initForm()
                    this._getData();
                    this.success()
                }else {
                    this.error(res.message)
                }
            })
        })
    }
    public cancel(){
        this.dialogFormVisible = false
        let form : Form = this.$refs['dataForm'] as Form;
        form.resetFields();
    }

    public show(row){
        let url : string  = this.$sprintf(Url.SHOW_APPLY, row.id);
        Request('get', url).then((res:any)=>{
            if (res.code == 200){
                this.showApplyDialog = true;
                this.DataDetail = res.data
            }else {
                this.error(res.message)
            }
        })
    }

    public revocation(row){
        if (row.deleted_at || row.audit_state_one != 0 || row.audit_state_two != 0){
            this.error("无法撤销")
            return
        }

        let url : string  = this.$sprintf(Url.DELETE_APPLY, row.id);
        Request('delete', url).then((res:any)=>{
            if (res.code == 200){
                this._getData();
                this.success()
            }else {
                this.error(res.message)
            }
        })
    }

    private async _getData()  {
        let url : string  = this.$sprintf(Url.APPLY, 1);
        const res:any = await Request('get', url,this.search)
        if (res.code == 200){
            this.Data = res.data.data
            this.total = res.data.total
        }else {
            this.error(res.message)
        }
    }

    private _initForm() {
        this.form = {item_id : null, send_account : null, reason : null}
    }

}