import { Component } from 'vue-property-decorator'
import "@/assets/js/wwlogin";
import HomeParent from "@/views/home/Common/HomeParent";
import SvgIcon  from '@/components/SvgIcon.vue'
import { Message } from 'element-ui';
import Web3 from 'web3'
import { Request } from "@/utils/Request";
import store from "@/views/home/store";
import Url from "@/utils/Url";


interface Window {
    ethereum: any
    web3: any
    celo: any
}
declare let window: Window

@Component({
    components : {
        SvgIcon
    }
})
export default class Login extends HomeParent {
    // @Action('Login') Login
    public provider:any
    public web3:Web3
    public chainId:number
    public account:string
    public nonce:string
    public isLogin:boolean

    public created(){
        if (store.state.token){
            this.isLogin = true
        }else {
            this.isLogin = false
        }
    }

    public async  doLogin(){
        if (!this.isLogin){
            try {
                await this.connect()
                await this.checkNance()
            } catch (err) {
                Message({
                    message: err.message,
                    type: 'error',
                    duration: 3 * 1000,
                })
                Promise.reject(err)
            }
        }else {
            Message({
                message: '已经登录过了！',
                type: 'warning',
                duration:2*1000,
                onClose:()=>{
                    this.goPage('home')
                }
            })
        }
    }

    private  async login( account, chainId, nonce) {
        nonce += ''
        const tips = 'This signature is only used for verify your account'
        const signMsg = {
            tips,
            nonce
        }
        const EIP721_DOMAIN_DATA = [
            { name: 'name', type: 'string' },
            { name: 'version', type: 'string' }
        ]

        const signObj = {
            types: {
                EIP712Domain: EIP721_DOMAIN_DATA,
                set: [
                    { name: 'tips', type: 'string' },
                    { name: 'nonce', type: 'string' }
                ]
            },
            primaryType: 'set',
            domain: {
                name: 'Auth',
                version: '1'
            },
            message: signMsg
        }
        const signature = await this.signData(signObj, account)
        const authData = {
            account,
            nonce,
            signature,
            tips,
            net_id: chainId
        }
        const res:any = await Request('post',Url.METAMASK_LOGIN,authData)

        if (res.code == 200) {
            store.commit('set_token',res.data.token)
            this.goPage("home");
        }
    }
    private  async  checkNance() {
        try {
            // store.commit('del_nonce');return
            let nonce = store.getters.nonce
            if (!nonce) {
                let params = {account:this.account, net_id:this.chainId}
                const res:any = await Request('get',Url.GET_NONCE,params)
                store.commit('set_nonce',res.data)
                this.nonce = res.data
            }
            this.login(this.account,this.chainId,store.getters.nonce)
        } catch (err) {
            Promise.reject(err)
        }
    }
    private async connect(){
        if (!this.hasMetamask()) {
            Message({
                message: '请先安装MetaMask插件',
                type: 'error',
                duration: 5 * 1000
            })
            return
        }
        this.provider = await  this.connectMetaMask()
        if (!this.provider) {
            return
        }

        this.web3 = new Web3(this.provider)
        this.chainId = await this.web3.eth.getChainId()
        const accounts = await this.web3.eth.getAccounts()
        if (accounts && accounts.length > 0) {
            this.account =accounts[0];
        }
    }
    private async connectMetaMask() {
        let  provider = window.ethereum
        try {
            await  provider.request({ method: 'eth_requestAccounts' })
        } catch (error) {
            if (error.code === -32002) {
                throw new Error('MeatMask not login, Open MeatMask and login first')
            } else {
                throw new Error('User Rejected')
            }
        }
        return provider
    }

    private hasMetamask():boolean {
        if (typeof window.ethereum !== 'undefined') {
            return  true;
        }else {
            return  false;
        }
    }
    private async signData(signObj: any, signer: string) {
        const msgParams = JSON.stringify(signObj)
        const from = signer
        const params = [from, msgParams]
        const result: any  = await this.sendCmd({
            method: 'eth_signTypedData_v4',
            params,
            from
        })
        return result.result
    }
    private async sendCmd({ method, params, from }:any) {
        return new Promise((resolve, reject) => {
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            this.web3.currentProvider.sendAsync({
                method,
                params,
                from
            }, async function(err: any, result: any) {
                if (err) {
                    reject && reject(err)
                    return
                }
                resolve && resolve(result)
            })
        })
    }

}