import { Component, Mixins, Vue, Watch } from 'vue-property-decorator'
import Url from "@/utils/Url";
import {
    State,
    Getter,
    Action,
    Mutation
} from "vuex-class";
import HomeParent from "@/views/home/Common/HomeParent";
import { ResponseInterface } from "@/utils/Http";
import { MenuInterface } from "@/views/home/Common/Types";
import {Form, TableColumn} from "view-design";
import CustomPage from "@/components/page.vue";
import {Request} from "@/utils/Request";

@Component({
    components : {
        CustomPage
    }
})
export default class Menus extends HomeParent {
    name : string = "Menus";
    public menus : MenuInterface[] = []
    public drawerTitle:string = '';
    public dialogFormVisible: boolean = false;
    public isEdit : boolean = false;
    public columns : any = [{
        // type : "selection",
        width : 80,
        key : "id"
    }, {
        title : "名称",
        key : "name",
        tree: true
    }, {
        title : "路径",
        key : "url"
    }, {
        title : "父菜单",
        slot : "parent"
    }, {
        title : "操作",
        slot : "operation"
    }]

    public form: any = {
        name : null,  url : null, pid : null
    }

    public rules: object = {
        name : [{required : true, trigger : "blur", "message" : "请填写菜单名称"}],
        pid : [{required : true, trigger : "selected", "message" : "请选择上级菜单"}],
        url : [{required : true, trigger : "blur", "message" : "请填写菜单路径"}],
    }

    public created() : void {
        this._getData();
    }

    public addMenu(){
        this.drawerTitle = '新增菜单'
        this.isEdit = false;
        this._initForm()
        this.dialogFormVisible = true
    }

    public  saveMenu(){
        let form : Form = this.$refs["dataForm"] as Form;
        form.validate((valid : boolean) => {
            if (!valid) {
                return;
            }
            this._saveMenu();
            // console.log(this.form)
        })
    }

    public editMenu(row){
        this.drawerTitle = '修改菜单'
        this.isEdit = true;
        this.form = {name : row.name, url : row.url, pid : row.pid,id:row.id};
        this.dialogFormVisible = true
    }

    public updateMenu(){
        let form : Form = this.$refs["dataForm"] as Form;
        form.validate((valid : boolean) => {
            if (!valid) {
                return;
            }
            this._saveMenu();
        })
    }

    public deleteMenus(row : MenuInterface) : void {
        let url = this.$sprintf(Url.DELETE_MENU, row.id);
        this.doDeleteItem("", () => {
            Request('delete', url).then((res:any)=>{
                if (res.code == 200){
                    this._getData();
                    this.success()
                }else {
                    this.error(res.message)
                }
            })
        })
    }

    private _saveMenu(){
        let url : string = Url.MENUS;
        let method  = 'post';
        if (this.isEdit){
            method = 'put';
            url = this.$sprintf(Url.UPDATE_MENU, this.form.id);
        }
        Request(method, url,this.form).then((res:any)=>{

            if (res.code == 200){
                this.dialogFormVisible = false
                this._initForm()
                this._getData();
                this.success()
            }else {
                this.error()
            }
        })
    }

    public cancel(){
        this.dialogFormVisible = false
        let form : Form = this.$refs['dataForm'] as Form;
        form.resetFields();
    }

    public parentName(row : MenuInterface, list : MenuInterface[] = this.menus) : string {
        let name : string = "";
        let idx : number = list.findIndex((item : MenuInterface) => item.id == row.pid);
        if (idx >= 0) {
            return list[idx].name;
        } else {
            for (let i : number = 0; i < list.length; i++) {
                name = this.parentName(row, list[i].children);
                if (name.length > 0) {
                    break;
                }
            }
        }
        return name;
    }

    private async _getData()  {
        const res:any = await Request('get', Url.MENUS)
        if (res.code == 200){
            this.menus = this._parseTreeData(res.data)
        }else {
            console.log(res.message)
            this.error(res.message)
        }

    }

    private _parseTreeData(list : any[]) {
        return list.map((item : any) => {
            if (item.children.length > 0) {
                item._showChildren = true;
                item.children = this._parseTreeData(item.children);
            }
            return item
        });
    }

    private _initForm() {
        this.form = { name : null,  url : null, pid : null}
    }
}