import { Component, Mixins, Vue, Watch } from 'vue-property-decorator'
import Url from "@/utils/Url";
import {
    State,
    Getter,
    Action,
    Mutation
} from "vuex-class";
import HomeParent from "@/views/home/Common/HomeParent";
import CustomPage from "@/components/page.vue";
import {ElTreeDataInterface, NodeGroupInterface, UserInterface} from "@/views/home/Common/Types";
import {Form, TableColumn} from "view-design";
import {Message, Tree} from "element-ui";
import {Request} from "@/utils/Request";

@Component({
    components : {
        CustomPage
    }
})
export default class PowerGroup extends HomeParent {
    name : string = "PowerGroup";
    public nodeGroups : NodeGroupInterface[] = [];
    public allNode : ElTreeDataInterface[] = [];
    public showNodeDialog : boolean = false;
    public checkNodeDefault = [];
    public drawerTitle:string = '';
    public dialogFormVisible: boolean = false;
    public form: any = { name : null };
    public rules: object = {
        name : [{required : true, trigger : "blur", "message" : "请填写权限组名称"}],
    }
    public columns : TableColumn[] = [{
        width: 80,
        key:'id'
    }, {
        title : "组名称",
        key : "name"
    },{
        title : "操作",
        width : 400,
        slot : "operation"
    }];

    public currentNodeGroup : NodeGroupInterface = null;

    public total : number = 0;

    public search : { page : number, size : number } = {
        page : 1, size : 10
    }

    @Watch("search.page")
    private _onPageChange() : void {
        this._getData()
    }

    @Watch("search.size")
    private _onPageSizeChange(): void {
        this.search.page = 1;
        this._getData()
    }

    public async initNodeData(row : UserInterface)  {
        this.currentNodeGroup = row;

        const res1:any = await Request('get', Url.NODE)
        if (res1.code == 200){
            this.allNode = this._parseElTreeData(res1.data)
            this.showNodeDialog = true;
        }else {
            console.log(res1.message)
        }
        let url = this.$sprintf(Url.SHOW_NODE_GROUP, row.id)
        const res2:any = await Request('get',url )
        if (res2.code == 200){
             this.checkNodeDefault = await res2.data.node
        }else {
            console.log(res2.message)
        }

    }

    public addNodeGroup()   {
        this.drawerTitle = '新增权限组'
        this._initForm()
        this.dialogFormVisible = true
    }

    public  saveNodeGroup(){
        let form : Form = this.$refs["dataForm"] as Form;
        form.validate((valid : boolean) => {
            if (!valid) {
                return;
            }
            Request('post', Url.NODE_GROUP,this.form).then((res:any)=>{
                if (res.code == 200){
                    this.dialogFormVisible = false
                    this._initForm()
                    this._getData();
                    this.success()
                }else {
                    this.error()
                }
            })
        })
    }

    public cancel(){
        this.dialogFormVisible = false
        let form : Form = this.$refs['dataForm'] as Form;
        form.resetFields();
    }


    public deletePowerGroup(row : NodeGroupInterface) : void {
        let url = this.$sprintf(Url.DELETE_NODE_GROUP, row.id);
        this.doDeleteItem("", () => {
            Request('delete', url).then((res:any)=>{
                if (res.code == 200){
                    this._getData();
                    this.success()
                }else {
                    this.error(res.message)
                }
            })
        })
    }


    public allotNode (){
        let tree : Tree  = this.$refs.treePower as Tree;
        let childrenIds = tree.getCheckedKeys();
        if (this.checkNodeDefault.toString() == tree.getCheckedKeys().toString()){
            this.$Message.warning('未做任何修改');
            return
        }
        let url : string  = this.$sprintf(Url.ALLOT_NODE, this.currentNodeGroup.id);
        Request('post', url,{'node_ids' : childrenIds}).then((res:any)=>{
            this.success()
            if (res.code == 200){
                this.checkNodeDefault =  res.data
            }
        })
    }

    public modalClose () {
        this.checkNodeDefault = []
    }

    public created() : void {
        this._getData();
    }


    private async _getData()  {
        const res:any = await Request('get', Url.NODE_GROUP,this.search)
        if (res.code == 200){
            this.nodeGroups = res.data.data
            this.total = res.data.total
        }else {
            console.log(res.message)
            this.error(res.message)
        }
    }

    private _parseElTreeData(list : any[]) {
        return list.map((item : any) => {
            return {
                id : item.id, label : item.name,
                children : this._parseElTreeData(item.children)
            };
        });
    }

    private _initForm() {
        this.form = {name : null}
    }

}